
History
=======

1.3
---

- added support for generic setup [SyZn, 2014-01-16]

1.2
---

- added zope.catalog compatible index. [jensens, 2012-04-12]

1.1
---

- eggification and release at pypi [jensens, 2011-03-08]

1.0
---

-  final release as Zope Product [jensens, 2007-08-29]

